import { useEffect, useState } from 'react';
import { DevSettings } from 'react-native';
import AsyncStorage from '@react-native-async-storage/async-storage';

const useDevSettings = items => {
  const [loading, setLoading] = useState(__DEV__);
  const [values, setValues] = useState([]);
  useEffect(() => {
    const keys = [];
    let res = '';
    let itemsResult = [];

    if (__DEV__) {
      items === null || items === void 0 ? void 0 : items.map(item => {
        item.action === undefined && keys.push(`@debug/${item.name.toLowerCase()}`);
      });
      AsyncStorage.multiGet(keys).then(result => {
        result.forEach(_ref => {
          var _res;

          let [key, value] = _ref;
          const parsedValue = Boolean(JSON.parse(value || 'false'));
          res = keys.find(item => key === item.toLowerCase());
          itemsResult.push({
            name: (_res = res) === null || _res === void 0 ? void 0 : _res.toLowerCase().slice(7),
            enabled: parsedValue
          });
        });
        setValues([...values, ...itemsResult]);
      });
    }

    setLoading(false);
  }, [!items]);
  useEffect(() => {
    if (!loading && __DEV__ && !!values) {
      items === null || items === void 0 ? void 0 : items.map(item => {
        var _values$find;

        let itemIsEnabled = (_values$find = values.find(value => (value === null || value === void 0 ? void 0 : value.name) === item.name.toLowerCase())) === null || _values$find === void 0 ? void 0 : _values$find.enabled;
        item.action === undefined ? DevSettings.addMenuItem(`Toggle ${item.name}`, () => {
          AsyncStorage.setItem(`@debug/${item.name.toLowerCase()}`, JSON.stringify(!itemIsEnabled));
          DevSettings.reload();
        }) : DevSettings.addMenuItem(`${item.name}`, () => {
          item.action && item.action();
          DevSettings.reload();
        });
      });
    }
  }, [loading, !items, values]);
  const state = {};

  for (let i = 0; i < values.length; i++) {
    if (values.length !== 0) {
      state[getKeyTransformed(values[i].name)] = values[i].enabled;
    }
  }

  return {
    loading,
    state
  };
};

const selectTheFirstLetter = /(^\w{1})|(\s+\w{1})/g;

const getKeyTransformed = key => {
  let transformedKey = key.replace(selectTheFirstLetter, letter => letter.toUpperCase().replace(" ", ""));
  return `use${transformedKey}`;
};

export default useDevSettings;
//# sourceMappingURL=useDevSettings.js.map